{% comment %}
Displays a list of Events.

Expects:
* event_list - List or Queryset of children of Event.
* style: 'bullets' (default) or 'unstyled'.

{% endcomment %}

{% if event_list|length > 0 %}
    <ul{% if style|default:'bullets' == 'unstyled' %} class="list-unstyled mb-0"{% endif %}>
        {% for event in event_list %}
            <li class="mb-2">
                <a href="{{ event.get_absolute_url }}"><strong>{{ event }}</strong><br>
                {% if event.venue %}{{ event.venue_name }}, {% endif %}{{ event.date|date:"j M Y" }}</a>
            </li>
        {% endfor %}
    </ul>
{% endif %}
