{% comment %}
For displaying a list of works that are attached to an Event by a ManyToManyField. e.g., Classical Works or Dance Pieces.

Expects:
* work_list - A list/QuerySet of ClassicalWorks, Movies, etc.
* heading - Optional text to use for the heading. If none, no heading is shown.
{% endcomment %}

{% if work_list|length > 0 %}
	{% if heading %}
		<h2>{{ heading }}</h2>
	{% endif %}

	<ul>
		{% for work in work_list %}
			{% include 'spectator_events/includes/work.html' with work=work only %}
		{% endfor %}
	</ul>
{% endif %}
