# Generated by Django 2.0 on 2018-01-25 17:56

from django.db import migrations


class Migration(migrations.Migration):
    """
    Remove the old ClassicalWork and DancePiece relationships to Events,
    now we've copied their data to the new version with a through model.
    """

    dependencies = [
        ('spectator_events', '0013_copy_classical_and_dance_data'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='event',
            name='classicalworks',
        ),
        migrations.RemoveField(
            model_name='event',
            name='dancepieces',
        ),
    ]
