
{% load spectator_core %}
{% current_url_name as url_name %}

<div class="card mb-3">
    <ul class="list-group list-group-flush">
        <li class="list-group-item">
            {% if url_name == 'spectator:creators:creator_list' %}
                Creators
            {% else %}
                <a href="{% url 'spectator:creators:creator_list' %}">Creators</a>
            {% endif %}
        </li>
    </ul>
</div>
