# Generated by Django 2.0 on 2018-01-29 17:35

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('spectator_events', '0020_venue_note'),
    ]

    operations = [
        migrations.AlterField(
            model_name='event',
            name='venue',
            field=models.ForeignKey(blank=True, on_delete=django.db.models.deletion.CASCADE, to='spectator_events.Venue'),
        ),
    ]
