# Generated by Django 2.0 on 2018-01-25 17:57

from django.db import migrations, models


class Migration(migrations.Migration):
    """
    Now we've deleted the old classicalworks and dancepieces fields,
    rename the new ones to be the same as the old.
    """

    dependencies = [
        ('spectator_events', '0014_remove_old_classical_dance'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='event',
            name='classicalworks2',
        ),
        migrations.RemoveField(
            model_name='event',
            name='dancepieces2',
        ),
        migrations.AddField(
            model_name='event',
            name='classicalworks',
            field=models.ManyToManyField(blank=True, help_text="Only used if event is of 'Classical Concert' kind.", through='spectator_events.ClassicalWorkSelection', to='spectator_events.ClassicalWork'),
        ),
        migrations.AddField(
            model_name='event',
            name='dancepieces',
            field=models.ManyToManyField(blank=True, help_text="Only used if event is of 'Dance' kind.", through='spectator_events.DancePieceSelection', to='spectator_events.DancePiece'),
        ),
    ]
