{% comment %}
Display next/prev year links.

Expects:

url_name -- The name of the URL to link to, including namespace, if any.
next -- date.
previous -- date.
{% endcomment %}

{% if next or previous %}
    <nav class="nextprev">
        <p class="row">
            {% if previous %}
                <span class="col-6">
                    <a href="{% url url_name year=previous|date:"Y" %}" class="btn btn-outline-primary">
                        &larr; {{ previous|date:'Y' }}
                    </a>
                </span>
            {% endif %}
            {% if next %}
                <span class="col-6{% if not previous %} ml-auto{% endif %}">
                    <a href="{% url url_name year=next|date:"Y" %}" class="btn btn-outline-primary float-right">
                        {{ next|date:'Y' }} &rarr;
                    </a>
                </span>
            {% endif %}
        </p>
    </nav>
{% endif %}
