{% extends 'spectator_events/base.html' %}

{% block head_page_title %}{{ event }}{% endblock %}
{% block content_title %}{{ event }}{% endblock %}

{% block breadcrumbs %}
    {{ block.super }}
    <li class="breadcrumb-item active">{{ event }}</li>
{% endblock %}

{% block content %}

    <p>
        {% if event.venue %}At <a href="{{ event.venue.get_absolute_url }}">{{ event.venue_name }}</a>
        on{% else %}On{% endif %} {{ event.date|date:"j M Y" }}.
    </p>

    {% if event.note %}
      {{ event.note|safe|linebreaks }}
    {% endif %}

    {% include 'spectator_core/includes/roles_list.html' with roles=event.roles.all heading='Featuring' only %}

    {% include 'spectator_events/includes/selections.html' with selection_list=event.get_movies heading="Movies" only %}

    {% include 'spectator_events/includes/selections.html' with selection_list=event.get_plays heading="Plays" only %}

    {% include 'spectator_events/includes/selections.html' with selection_list=event.get_classical_works heading="Works" only %}

    {% include 'spectator_events/includes/selections.html' with selection_list=event.get_dance_pieces heading="Pieces" only %}

{% endblock content %}


{% block sidebar %}
    {% load spectator_core %}
    {% change_object_link_card object perms %}

    {{ block.super }}
{% endblock %}
